ServiceState<T> class sealed

Implementers

Properties

error → Object?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isUpdating → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
no setter
value → T
no setter

Methods

map<T2>(T2 f(T)) → ServiceState<T2>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<T2>({required T2 idle(ServiceStateIdle<T>), required T2 updating(ServiceStateUpdating<T>), required T2 error(ServiceStateError<T>)}) → T2
whenOrNull<T2>({T2 idle(ServiceStateIdle<T>)?, T2 updating(ServiceStateUpdating<T>)?, T2 error(ServiceStateError<T>)?}) → T2?

Operators

operator ==(Object other) → bool
The equality operator.
inherited